Module changeset

Module changeset 

Structs

ChangesetId
Stable identity of one changeset file without its storage location.

Enums

BumpLevel
Semantic version change requested for one package.
PlanWarning
Non-fatal domain condition to render alongside a release plan.
ReleaseReason
Why a package is included in a release.